You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by pi...@apache.org on 2007/03/30 16:06:51 UTC

svn commit: r524093 - in /webservices/axis2/trunk/c: axiom/src/om/ samples/server/mtom/ util/include/ util/src/

Author: pini
Date: Fri Mar 30 07:06:50 2007
New Revision: 524093

URL: http://svn.apache.org/viewvc?view=rev&rev=524093
Log:
Fixing jira issue 292

Added:
    webservices/axis2/trunk/c/util/include/axutil_base64.h
      - copied, changed from r524047, webservices/axis2/trunk/c/util/include/axis2_base64.h
Removed:
    webservices/axis2/trunk/c/util/include/axis2_base64.h
Modified:
    webservices/axis2/trunk/c/axiom/src/om/om_data_source.c
    webservices/axis2/trunk/c/axiom/src/om/om_text.c
    webservices/axis2/trunk/c/samples/server/mtom/mtom.c
    webservices/axis2/trunk/c/util/include/axutil_base64_binary.h
    webservices/axis2/trunk/c/util/src/base64.c
    webservices/axis2/trunk/c/util/src/base64_binary.c

Modified: webservices/axis2/trunk/c/axiom/src/om/om_data_source.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/axiom/src/om/om_data_source.c?view=diff&rev=524093&r1=524092&r2=524093
==============================================================================
--- webservices/axis2/trunk/c/axiom/src/om/om_data_source.c (original)
+++ webservices/axis2/trunk/c/axiom/src/om/om_data_source.c Fri Mar 30 07:06:50 2007
@@ -23,7 +23,7 @@
 #include <axiom_output.h>
 #include <axiom_attribute.h>
 #include <axiom_namespace.h>
-#include <axis2_base64.h>
+#include <axutil_base64.h>
 
 
 /********************* axiom_data_source_struct ***************/

Modified: webservices/axis2/trunk/c/axiom/src/om/om_text.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/axiom/src/om/om_text.c?view=diff&rev=524093&r1=524092&r2=524093
==============================================================================
--- webservices/axis2/trunk/c/axiom/src/om/om_text.c (original)
+++ webservices/axis2/trunk/c/axiom/src/om/om_text.c Fri Mar 30 07:06:50 2007
@@ -23,7 +23,7 @@
 #include <axiom_output.h>
 #include <axiom_attribute.h>
 #include <axiom_namespace.h>
-#include <axis2_base64.h>
+#include <axutil_base64.h>
 
 static const axis2_char_t *AXIS2_CALL
 axiom_text_get_text(axiom_text_t *om_text,
@@ -500,11 +500,11 @@
                 &data_handler_stream, &data_handler_stream_size);
             if (data_handler_stream)
             {
-                encoded_len = axis2_base64_encode_len(data_handler_stream_size);
+                encoded_len = axutil_base64_encode_len(data_handler_stream_size);
                 encoded_str = AXIS2_MALLOC(env->allocator, encoded_len);
                 if (encoded_str)
                 {
-                    encoded_len = axis2_base64_encode(encoded_str,
+                    encoded_len = axutil_base64_encode(encoded_str,
                         data_handler_stream, data_handler_stream_size);
                     encoded_str[encoded_len] = '\0';
                     return encoded_str;

Modified: webservices/axis2/trunk/c/samples/server/mtom/mtom.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/mtom/mtom.c?view=diff&rev=524093&r1=524092&r2=524093
==============================================================================
--- webservices/axis2/trunk/c/samples/server/mtom/mtom.c (original)
+++ webservices/axis2/trunk/c/samples/server/mtom/mtom.c Fri Mar 30 07:06:50 2007
@@ -101,10 +101,10 @@
                         
                         axis2_char_t *base64text = (axis2_char_t *)axiom_text_get_value(bin_text, env);
                         printf("base64text = %s\n", base64text);
-                        plain_binary_len = axis2_base64_decode_len(base64text);
+                        plain_binary_len = axutil_base64_decode_len(base64text);
                         plain_binary =  AXIS2_MALLOC(env->
                                     allocator, sizeof(unsigned char) * plain_binary_len);
-                        axis2_base64_decode_binary((unsigned char*)plain_binary,
+                        axutil_base64_decode_binary((unsigned char*)plain_binary,
                                     base64text);
                         data_handler = axiom_data_handler_create(env, text_str, NULL);
                         AXIOM_DATA_HANDLER_SET_BINARY_DATA(data_handler, env, plain_binary, plain_binary_len);

Copied: webservices/axis2/trunk/c/util/include/axutil_base64.h (from r524047, webservices/axis2/trunk/c/util/include/axis2_base64.h)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_base64.h?view=diff&rev=524093&p1=webservices/axis2/trunk/c/util/include/axis2_base64.h&r1=524047&p2=webservices/axis2/trunk/c/util/include/axutil_base64.h&r2=524093
==============================================================================
--- webservices/axis2/trunk/c/util/include/axis2_base64.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_base64.h Fri Mar 30 07:06:50 2007
@@ -16,7 +16,7 @@
 
 #include <axis2_utils_defines.h>
 /*
- * @file axis2_base64.h
+ * @file axutil_base64.h
  * @brief AXIS2-UTIL Base64 Encoding
  */
 #ifndef AXIS2_BASE64_H
@@ -50,7 +50,7 @@
  * @param len the length of an unencrypted string.
  * @return the length of the string after it is encrypted
  */ 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_encode_len(int len);
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_encode_len(int len);
 
 /*
  * Encode a text string using base64encoding.
@@ -59,7 +59,7 @@
  * @param len_plain_src The length of the plain text string
  * @return the length of the encoded string
  */ 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_encode(char * coded_dst, const char *plain_src, 
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_encode(char * coded_dst, const char *plain_src, 
                                  int len_plain_src);
 
 /*
@@ -69,7 +69,7 @@
  * @param len_plain_src The length of the plain text string
  * @return the length of the encoded string
  */ 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_encode_binary(char * coded_dst, 
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_encode_binary(char * coded_dst, 
                                         const unsigned char *plain_src,
                                         int len_plain_src);
 
@@ -78,7 +78,7 @@
  * @param coded_src The encoded string
  * @return the length of the plain text string
  */ 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_decode_len(const char * coded_src);
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_decode_len(const char * coded_src);
 
 /*
  * Decode a string to plain text
@@ -86,7 +86,7 @@
  * @param coded_src The encoded string 
  * @return the length of the plain text string
  */ 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_decode(char * plain_dst, const char *coded_src);
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_decode(char * plain_dst, const char *coded_src);
 
 /*
  * Decode an EBCDIC string to plain text
@@ -94,7 +94,7 @@
  * @param coded_src The encoded string 
  * @return the length of the plain text string
  */ 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_decode_binary(unsigned char * plain_dst, 
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_decode_binary(unsigned char * plain_dst, 
                                         const char *coded_src);
 
 /* @} */

Modified: webservices/axis2/trunk/c/util/include/axutil_base64_binary.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_base64_binary.h?view=diff&rev=524093&r1=524092&r2=524093
==============================================================================
--- webservices/axis2/trunk/c/util/include/axutil_base64_binary.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_base64_binary.h Fri Mar 30 07:06:50 2007
@@ -18,7 +18,7 @@
 #ifndef AXIS2_BASE64_BINARY_H
 #define AXIS2_BASE64_BINARY_H
 
-#include <axis2_base64.h>
+#include <axutil_base64.h>
 #include <axis2_utils_defines.h>
 #include <axis2_env.h>
 

Modified: webservices/axis2/trunk/c/util/src/base64.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/src/base64.c?view=diff&rev=524093&r1=524092&r2=524093
==============================================================================
--- webservices/axis2/trunk/c/util/src/base64_binary.c (original)
+++ webservices/axis2/trunk/c/util/src/base64_binary.c Fri Mar 30 07:06:50 2007
@@ -91,7 +91,7 @@
         return NULL;
     }
 
-    plain_binary_len = axis2_base64_decode_len(encoded_binary);
+    plain_binary_len = axutil_base64_decode_len(encoded_binary);
     base64_binary->plain_binary =  AXIS2_MALLOC(env->allocator, 
         sizeof(unsigned char) * plain_binary_len);
 
@@ -101,7 +101,7 @@
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_base64_decode_binary(base64_binary-> plain_binary,
+    axutil_base64_decode_binary(base64_binary-> plain_binary,
             encoded_binary);
     base64_binary-> plain_binary_len = plain_binary_len;
 
@@ -166,7 +166,7 @@
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
 
-    plain_binary_len = axis2_base64_decode_len(encoded_binary);
+    plain_binary_len = axutil_base64_decode_len(encoded_binary);
     base64_binary->plain_binary =  AXIS2_MALLOC(env->
             allocator, sizeof(unsigned char) * plain_binary_len);
 
@@ -176,7 +176,7 @@
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return AXIS2_FAILURE;
     }
-    axis2_base64_decode_binary(base64_binary-> plain_binary,
+    axutil_base64_decode_binary(base64_binary-> plain_binary,
             encoded_binary);
     base64_binary-> plain_binary_len = plain_binary_len;
 
@@ -190,7 +190,7 @@
     char* encoded_binary = NULL;
     int encoded_binary_len = 0;
 
-    encoded_binary_len = axis2_base64_encode_len(
+    encoded_binary_len = axutil_base64_encode_len(
                 base64_binary-> plain_binary_len);
     encoded_binary = AXIS2_MALLOC(env-> allocator,
             sizeof(char) * encoded_binary_len);
@@ -201,7 +201,7 @@
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_base64_encode_binary(encoded_binary,
+    axutil_base64_encode_binary(encoded_binary,
             base64_binary-> plain_binary,
             base64_binary-> plain_binary_len);
     return encoded_binary;
@@ -213,7 +213,7 @@
         const axis2_env_t *env)
 {
     int encoded_binary_len = 0;
-    encoded_binary_len = axis2_base64_encode_len(
+    encoded_binary_len = axutil_base64_encode_len(
                 base64_binary-> plain_binary_len);
     return encoded_binary_len;
 }



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/util/src/base64.c (original)
+++ webservices/axis2/trunk/c/util/src/base64.c Fri Mar 30 07:06:50 2007
@@ -22,7 +22,7 @@
  * ugly 'len' functions, which is quite a nasty cost.
  */
 
-#include <axis2_base64.h>
+#include <axutil_base64.h>
 
 static const unsigned char pr2six[256] =
     {
@@ -90,7 +90,7 @@
 
 #endif /* __OS400__ */
 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_decode_len(const char *bufcoded)
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_decode_len(const char *bufcoded)
 {
     int nbytesdecoded;
     register const unsigned char *bufin;
@@ -105,19 +105,19 @@
     return nbytesdecoded + 1;
 }
 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_decode(char *bufplain, const char *bufcoded)
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_decode(char *bufplain, const char *bufcoded)
 {
     int len;
-    len = axis2_base64_decode_binary((unsigned char *) bufplain, bufcoded);
+    len = axutil_base64_decode_binary((unsigned char *) bufplain, bufcoded);
     bufplain[len] = '\0';
     return len;
 }
 
 /* This is the same as axis2_base64_decode() except on EBCDIC machines, where
  * the conversion of the output to ebcdic is left out.
  */
 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_decode_binary(unsigned char *bufplain,
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_decode_binary(unsigned char *bufplain,
         const char *bufcoded)
 {
     int nbytesdecoded;
@@ -169,15 +169,15 @@
 static const char basis_64[] =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_encode_len(int len)
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_encode_len(int len)
 {
     return ((len + 2) / 3 * 4) + 1;
 }
 
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_encode(char *encoded, const char *string, int len)
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_encode(char *encoded, const char *string, int len)
 {
 #ifndef __OS400__
-    return axis2_base64_encode_binary(encoded, (const unsigned char *) string, len);
+    return axutil_base64_encode_binary(encoded, (const unsigned char *) string, len);
 #else /* __OS400__ */
     int i;
     char *p;
@@ -214,10 +214,10 @@
 #endif                /* __OS400__ */
 }
 
 /* This is the same as axis2_base64_encode() except on EBCDIC machines, where
  * the conversion of the input to ascii is left out.
  */
-AXIS2_EXTERN int AXIS2_CALL axis2_base64_encode_binary(char *encoded,
+AXIS2_EXTERN int AXIS2_CALL axutil_base64_encode_binary(char *encoded,
         const unsigned char *string, int len)
 {
     int i;
@@ -105,19 +105,19 @@
 }
 
-/* This is the same as axis2_base64_decode() except on EBCDIC machines, where
+/* This is the same as axutil_base64_decode() except on EBCDIC machines, where
  * the conversion of the output to ebcdic is left out.
  */
@@ -214,10 +214,10 @@
 }
 
-/* This is the same as axis2_base64_encode() except on EBCDIC machines, where
+/* This is the same as axutil_base64_encode() except on EBCDIC machines, where
  * the conversion of the input to ascii is left out.
  */

Modified: webservices/axis2/trunk/c/util/src/base64_binary.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/src/base64_binary.c?view=diff&rev=524093&r1=524092&r2=524093
==============================================================================